@@ -1,18 +1,20 @@
 # flake8: noqa
 from .config import Config
-from .users import User
-from .products import Product, Seuil
+from .users import User, Profil
+from .products import Product, Seuil, LotRetire, TopFive
 from .ucd import Ucd
 from .cip import Cip
 from .labels import Label
 
-from .patient import Patient
+from .patient import (Patient, Patient_Histo)
 from .sejour import Sejour
 from .service import Service
 from .prescription import Prescription, PrescriptionItem
-from .dispensation import Dispensation, DispensationItem
+from .dispensation import Dispensation, DispensationItem, FListe, FItem, FListeError
+from .emplacements import Emplacements
 
-from .magasin import Magasin, Adresse, Compteur
+
+from .magasin import Magasin, Adresse, Compteur, Espace, MagasinService, Zone, ZoneMag
 from .stock import Stock
 from .gpao import Gpao
 from .historique import (
@@ -26,3 +28,8 @@ from .historique import (
     HistoriquePrise,
     HistoriqueSachet,
 )
+from .log import LogAstus, MessageAstus
+
+from .menu import Web_Menu, Web_Menu_i18n
+
+from .suivi_production import SuiviProd
